pub struct IanaNames<'data> {
pub normalized_iana_ids: VarZeroVec<'data, str>,
}Expand description
A mapping from IANA time zone identifiers to BCP-47 time zone identifiers.
The BCP-47 time zone ID maps to the default IANA time zone ID according to the CLDR data.
๐ง This code is considered unstable; it may change at any time, in breaking or non-breaking ways,
including in SemVer minor releases. While the serde representation of data structs is guaranteed
to be stable, their Rust representation might not be. Use with caution.
Fields
normalized_iana_ids: VarZeroVec<'data, str>The list of all normalized IANA identifiers.
The first bcp47_ids.len() identifiers are canonical for the
the BCP-47 IDs in IanaToBcp47Map::bcp47_ids at the same index.
The remaining non-canonical identifiers are sorted in ascending lowercase order.