pub struct IanaToBcp47Map<'data> {
pub map: ZeroAsciiIgnoreCaseTrie<ZeroVec<'data, u8>>,
pub bcp47_ids: ZeroVec<'data, TimeZone>,
}Expand description
A mapping from normal-case IANA time zone identifiers to BCP-47 time zone identifiers.
Multiple IANA time zone IDs can map to the same BCP-47 time zone ID.
๐ง This code is considered unstable; it may change at any time, in breaking or non-breaking ways,
including in SemVer minor releases. While the serde representation of data structs is guaranteed
to be stable, their Rust representation might not be. Use with caution.
Fields
map: ZeroAsciiIgnoreCaseTrie<ZeroVec<'data, u8>>A map from normal-case IANA time zone identifiers to indexes of BCP-47 time zone identifiers along with a canonical flag. The IANA identifiers are normal-case.
The usize values stored in the trie have the following form:
- Lowest bit: 1 if canonical, 0 if not canonical
- All remaining bits: index into
bcp47_ids
For example, in CLDR 44, "Africa/Abidjan" has value 221, which means it is canonical
(low bit is 1 == odd number) and the index into bcp47_ids is 110 (221 >> 1).
bcp47_ids: ZeroVec<'data, TimeZone>A list of BCP-47 time zone identifiers, sorted by canonical IANA ID.